@@ -23,17 +23,21 @@ def invoke_protoc(argv):
     Args:
         argv: protoc CLI invocation, first item must be 'protoc'
     """
+
+    # Add current directory to include path if nothing else is specified
+    if not [x for x in argv if x.startswith('-I')]:
+        argv.append("-I.")
+
+    # Add default protoc include paths
+    nanopb_include = os.path.dirname(os.path.abspath(__file__))
+    argv.append('-I' + nanopb_include)
+
     if has_grpcio_protoc():
         import grpc_tools.protoc as protoc
         import pkg_resources
         proto_include = pkg_resources.resource_filename('grpc_tools', '_proto')
-        nanopb_include = os.path.dirname(os.path.abspath(__file__))
-
-        if not [x for x in argv if x.startswith('-I')]:
-            argv = argv + ["-I."]
-
-        argv = argv + ['-I' + proto_include, '-I' + nanopb_include]
+        argv.append('-I' + proto_include)
 
         return protoc.main(argv)
     else:
-        return subprocess.check_call(argv)
+        return subprocess.call(argv)
