@@ -17,16 +17,16 @@ mkdir -p $DEST
 git archive HEAD | tar x -C $DEST
 
 # Rebuild the Python .proto files and .pyc
-( cd $DEST/generator; python nanopb_generator.py ||: )
+( cd $DEST/generator; py -3 nanopb_generator.py ||: )
 
 # Package the Python libraries
-( cd $DEST/generator; pyinstaller nanopb_generator.py  )
-( cd $DEST/generator; pyinstaller protoc  )
+( cd $DEST/generator; py -3 -m PyInstaller nanopb_generator.py  )
+( cd $DEST/generator; py -3 -m PyInstaller protoc  )
 mv $DEST/generator/dist/nanopb_generator $DEST/generator-bin
 cp $DEST/generator/dist/protoc/protoc.exe $DEST/generator-bin
 
-# Include Google's descriptor.proto and related
-cp -pr $(python -c 'import grpc_tools, os.path; print(os.path.dirname(grpc_tools.__file__))')/_proto $DEST/generator-bin/grpc_tools/
+# Include Google's descriptor.proto and nanopb.proto
+cp -pr $(py -3 -c 'import grpc_tools, os.path; print(os.path.dirname(grpc_tools.__file__))')/_proto $DEST/generator-bin/grpc_tools/
 cp -pr $DEST/generator/proto $DEST/generator-bin/proto
 
 # Remove temp files
